<?php
session_start();
// PJC 24-JUL-2020 - 096 iPCS
// PJC 13-JUL-2020 - Update SIP Wizard to SIP / Team Wizard, redirect to Admin Portal
// PJC 13-DEC-2018 - Show PCS/SSL, WebPatch & WebUprade on VMAP	  	
// PJC 10-OCT-2018 - Hide DiskSpace, WebPatch, WebUpgrade,patch & upgrade vmap
// PJC 29-JUN-2018 - Added 092 inittab
// PJC 24-JAN-2017 - Added 091 Notifications
// PJC 30-DEC-2016 - Added 090 TCPDUMP
// PJC 30-DEC-2016 - Added FILEMAN
// PJC 15-NOV-2016 - Added PortalAudit S8000
// PJC 28-Jan-2016 - Fix hidden entries after search
// PJC 08-Jan-2016 - remove unnecessary blank lines
// PJC 05-Jan-2016 - filter update, hide empty sub sections
// PJC 29-DEC-2015 - pcs_defaults
// PJC 04-FEB-2015 - filtering update
// PJC 18-Dec-2014 - access date exception / schedule call updates
// PJC 15-Dec-2014 - access for import / export
// PJC 01-Dec-2014 - access
// PJC 14-Oct-2014 - grouped departments
// PJC 06-Oct-2014 - alternate routing
// PJC 28-Aug-2014 - bulk departments = voicemail contacts user/departments
// PJC 22-July-2014 - FTPBackup
// PJC 14-July-2014 - Change SSL Wording
// PJC 04-July-2014 - Change SSL order
// PJC 26-June-2014 - slide sections to top
// PJC 06-05-2014 - Search Scripts updated filtering, input hover - no autocomplete
// PJC 06-05-2014 - Search Scripts
$page_id="000";
$manager_user = ($_SERVER['PHP_AUTH_USER']); $ma = NULL;
if ($manager_user != "Manager") {
	if (!isset($_SESSION[$manager_user])) include ".access.php";
	$ma = $_SESSION[$manager_user];
}

$date_access=$sch='';

$ds = ldap_connect("127.0.0.1",4000);
if ( ! $ds) {
	echo "LDAP connect failure<br>";
} else {
$r = ldap_bind($ds,"INTERNAL","0123456");
	if ( ! $r) {
		echo "LDAP bind failure<br>";
		$ds = false;
	}
}

$sr = ldap_read($ds,"cn=Self,cn=Modules","objectclass=*"); 
$info = ldap_get_entries($ds,$sr); 
$self = $info[0]['location'][0];

$sr = ldap_read($ds,"cn=$self,cn=Modules","objectclass=module"); 
$info = ldap_get_entries($ds,$sr); 
$productversion = $info[0]['productversion'][0];

function check($id, $str, $ma) {
	global $manager_user;
	if ($manager_user == "Manager") {
		echo $str;
	} elseif (preg_match('/'.$id.'/',$ma)) echo $str;
}

	$files_ma ='';
	if ($manager_user == 'Manager') $files_ma = 'Area Codes, Contacts, Dial Plan, DDI Call Plans, LCR Plans And Users';
	
	$arr = array();
	if (strpos($ma,'061a') !== false) $arr[] =  'Area Codes';
	if (strpos($ma,'061b') !== false) $arr[] =  'Contacts';
	if (strpos($ma,'061c') !== false) $arr[] =  'Dial Plans';
	if (strpos($ma,'061d') !== false) $arr[] =  'DDI Call Plans';
	if (strpos($ma,'061e') !== false) $arr[] =  'LCR Plans';
	if (strpos($ma,'061f') !== false) $arr[] =  'Users';
	$last = array_pop($arr);
	$files_ma = count($arr) ? implode(", ", $arr) . " and " . $last : $last;
	
	$model = (file_exists('/SpliceCom/model')) ? file_get_contents('/SpliceCom/model') : 'NotCS5100';
	
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html>
<title>Manager Assist</title>
<head>
<meta http-equiv="Content-type" content="text/html; charset=UTF-8"/>
<link href="css/Styles.css" rel="stylesheet" type="text/css">
<script src="js/wiz/jquery-1.8.0.js" type="text/javascript"></script>
<?php
if (strpos($_SERVER['HTTP_USER_AGENT'],'Macintosh') == false)
echo "<script src='js/wiz/main.js' type='text/javascript'></script>";
?>
<script type="text/javascript">
$(window).bind("pageshow", function(event) {
    if (event.originalEvent.persisted) {
        window.location.reload() 
    }
});

$(document).ready(function () {
   	$("#filter").focus();
	
	$(".section").each(function(i){
		if(($(this).find('a').length)<2) $(this).hide();
	});
	
	$(".sub").each(function(i){
		if(($(this).find('a').length)<1) $(this).hide();
	});
	
    $('.slideassist').hide(800);
    $('a#show').on('click', function (e) {
		$('.sub').show();
	    
	    var search = $('#filter').val();   
	    if (search.length >0) {
		 	$('#filter').val('');
		 	$(".tooltip").each(function(){ $(this).show(); });   
		 	$("#filter-count").text('');
	    }
	    
        e.preventDefault();
        var elem = $(this).next('.slideassist')
        $('.slideassist').not(elem).hide(800);
        elem.toggle(850);
        setTimeout(function(){$('html, body').animate({
    	scrollTop: elem.offset().top -85
		}, 1200);}, 810);
    });

    $("#filter").keyup(function(){
        // Retrieve the input field text and reset the count to zero
        var filter = $(this).val(), count = 0; 
        if(filter.length > 0)
        {
            $(".tooltip").not('#show').not('#faq').css("display","none");
			$('.sub').hide();
           
            // Loop through the list
            $(".tooltip").not('#show').not('#faq').each(function(){
                if (($(this).text().search(new RegExp(filter, "i")) > -1) || ($(this).attr('title').search(new RegExp(filter, "i")) > -1))  
                {
                    $(this).show().closest(".slideassist").show(); 
					$(this).show().closest(".sub").show(); 
                    count++;
                }
            });
            $('.slideassist').each(function()
               {
                   if($(this).find("a:visible").length == 0)
                   $(this).hide();
               });            
        } 
        else
        {
            $('.slideassist').hide();
			$(".tooltip").each(function(){ $(this).show(); });
        }            
        // Update the count
        var numberItems = count;
        $("#filter-count").text("Number of Scripts = "+count);
    });
    
      	$("#filter").hover(function () {
         	$(this).focus();
     	});
     	
     	    $('#manager_name').on('click', function (e) {
	     	    $.ajax({ url : 'log/reset.php?clear_manager_access=' + $(this).text() })
					.done(function(data) { location.reload(); });
     	    });
    	
});
</script>
<style>
html { overflow-y: scroll; }
p { margin-bottom:0; }
</style>
</head>
<body>
<div style="position:absolute; top:8px; right:8px;" >
<img onClick="window.location = 'assist.php'" src="images/refresh16.gif" alt="refresh" title="refresh" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'assist.php'" src="images/assist16.gif" alt="manager assist" title="manager assist" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'index.php'" src="images/home16.gif" alt="home" title="home" border="0">
</div>
<div class="assist" style="width:600px; margin: 50px auto 0;">
<div id="navcontainer" >
<img src='images/manager_assist_OS.png' style="vertical-align:middle;width:601px;">
<ul id="navlist">
<b>Administrator</b>: 
<?php 
if ($manager_user == 'Manager') { 
	echo "<a href ='ma_access.php' style='text-decoration: none; color:#202020;'>$manager_user</a>";
}else {
	echo "<span id='manager_name'>$manager_user</span>";
}
?>

<br/><br/>
Please click on the links below to view the scripts in that section or<br/>use the search tool to locate a script.<br/><br/>
<form id="live-search" action="" method="post">
Search Scripts : 
        <input type="text" class="text-input" id="filter" value="" autocomplete="off"/><a href='#' class='tooltip' id='show' title='The Full Script Description and ToolTip Is Searched For A Partial Match. Filtered Results Are Shown Below.'><img src='images/tooltip.jpg'></a><br/>
        <span id="filter-count"></span>
</form><br/>

<?php check("CMD","<li><a href='#' id='show' class='tooltip' title='Command Line Scripts'><h3><img src='images/web.png' style='vertical-align:middle;'>&nbsp;&nbsp;Command Line Scripts</h3></a>
<div class='slideassist' style='display:block; display:none;'>
	<a href='commandline.php#clear' class='tooltip' title='/ftp/clear - Clear Old Cores, Admin_Logs Etc'><b>/ftp/clear</b> - Clear Old Cores, Admin_Logs Etc</a>
	<a href='commandline.php#clear1' class='tooltip' title='/ftp/clear1 - Clear Old Cores, Admin_Logs Etc. Better When Lots On A 41XX'><b>/ftp/clear1</b> - As above but better on 41xx hardware</a>
	<a href='commandline.php#clear2' class='tooltip' title='/ftp/clear2 - Clear Old Calls_Logs Etc In /ftp'><b>/ftp/clear2</b> - Clear Old Calls_Logs Etc In /ftp</a>
	<a href='commandline.php#calls' class='tooltip' title='/WebManager/calls.php - Collect Call Log Info For Each Day In /SpliceCom/Web/Download/'><b>calls.php</b> - Collect Call Log Info For Each Day In /SpliceCom/Web/Download/</a>
	<a href='commandline.php#check' class='tooltip' title='/WebManager/check.php - Daily Checks On Call Server, Can Be Run Via CronTab'><b>check.php</b> - Daily Checks On Call Server</a>
	<a href='commandline.php#crcx' class='tooltip' title='/WebManager/crcx.php - Extract CRC Detail For A Call From Admin Logs'><b>crcx.php</b> - Extract CRC Detail For A Call From Admin Logs</a>
	<a href='commandline.php#dobackup' class='tooltip' title='/WebManager/dobackup.php - Backup System Configuration'><b>dobackup.php</b> - Backup System Configuration</a>
	<a href='commandline.php#doreboot' class='tooltip' title='/WebManager/doreboot.php - Reboot System'><b>doreboot.php</b> - Reboot System</a>
	<a href='commandline.php#dosetmaster' class='tooltip' title='Do Ask/Set Master'><b>dosetmaster.php</b> - Do Ask/Set Master</a>
	<a href='commandline.php#extract' class='tooltip' title='/WebManager/extract.php - Extract Calls From Admin Log Etc'><b>extract.php</b> - Extract Calls From Admin Log Etc</a>
	<a href='commandline.php#ftpbackup' class='tooltip' title='/WebManager/ftpbackup.php - Create and FTP Upload System Backup Files'><b>ftpbackup.php</b> - Create and FTP Upload System Backup Files</a>", $ma);
	
	if (! file_exists('/SpliceCom/install/assets/vmap')){
		check("CMD","<a href='commandline.php#patch' class='tooltip' title='/WebManager/patch.php - Automated Software Upgrade, Can Be Run Via CronTab'><b>patch.php</b> - Automated Software Upgrade</a>", $ma);
	}
	
	check("CMD","<a href='commandline.php#sipx' class='tooltip' title='/WebManager/sipx.php - Extract SIP Detail For A Call From Admin Logs'><b>sipx.php</b> - Extract SIP Detail For A Call From Admin Logs</a>
	<a href='commandline.php#unstick' class='tooltip' title='/WebManager/unstick.php - Clear A Call Stuck For Over An Hour'><b>unstick.php</b> - Clear A Call Stuck For Over An Hour</a>", $ma);
	
	if (! file_exists('/SpliceCom/install/assets/vmap')){
		check("CMD","<a href='commandline.php#upgrade' class='tooltip' title='/WebManager/upgrade.php - Upgrade All Modules And PCSXXX'S, Can Be Run Via CronTab'><b>upgrade.php</b> - Upgrade All Modules And PCSxxx's</a>", $ma);
	}
check("CMD","</div>
</li>", $ma); ?>

<li><div class='section'>
<a href="#" id="show" class='tooltip' title="A Collection Of Scripts To Aid With The Configuration Of The System"><h3><img src='images/settings.png' style="vertical-align:middle;">&nbsp;&nbsp;Configuration Aids</h3></a>
<div class="slideassist" style="display:block; display:none;">
	<div class='sub'><strong class='strong'>Configuration</strong>
	<?php
		check("079","<a href='deptoverview.php' class='tooltip' title='View and Search All Departments'><b>Departments</b> - Department Overview</a>", $ma);
		check("081","<a href='adddepartment.php' class='tooltip' title='Add New Department'><b>Departments</b> - Add New Department</a>", $ma);
		check("084","<a href='groupoverview.php' class='tooltip' title='View and Search All Groups'><b>Groups</b> - Group Overview</a>", $ma);
		check("082","<a href='creategroup.php' class='tooltip' title='Create new Group'><b>Groups</b> - Create New Group</a>", $ma);
		check("078","<a href='useroverview.php' class='tooltip' title='View and Search All Users'><b>Users</b> - User Overview</a>", $ma);
		check("080","<a href='adduser.php' class='tooltip' title='Add New User'><b>Users</b> - Add New User</a>", $ma);
	?>
	<br/></div>
	
	<div class='sub'><strong class='strong'>Departments</strong>
	
	<?php
		if (strpos($productversion, 'SV') !== false || strpos($productversion, 'S8') !== false) {
			check("001","<a href='bulk_departments.php?action=1' class='tooltip' title='Add Bulk Departments/Queues'><b>Departments</b> - Add Bulk Departments/Queues</a>", $ma);
		} else {
			check("001","<a href='bulk_departmentscs.php?action=1' class='tooltip' title='Add Bulk Departments'><b>Departments</b> - Add Bulk Departments</a>", $ma);
		}
		
		  check("002","<a href='add_vmcontacts.php?action=1' class='tooltip' title='Add Bulk Voicemail Contacts To A Department'><b>Departments</b> - Bulk Add Voicemail Contacts</a>", $ma);
		  check("079","<a href='deptoverview.php' class='tooltip' title='View and Search All Departments'><b>Departments</b> - Department Overview</a>", $ma);
		  check("003","<a href='/manager/fixed.php' class='tooltip' title='Display Department Config, Highlight and Fix Issues'><b>Departments</b> - Display, Highlight and Fix Department Configuration Issues</a>", $ma);
	 	  check("004","<a href='depts_groups_users.php' class='tooltip' title='View Which Users, Groups And Timeplans Are Associated With A Department'><b>Departments</b> - View Associated Users, Groups, DDI's & Timeplans</a>", $ma);
	 	  check("005","<a href='dept_vmmon.php' class='tooltip' title='View, Add and Remove Which Users Are Monitoring A Departments Voicemail'><b>Departments</b> - View, Add, Remove Voicemail Monitors</a>", $ma);
	 	  check("006","<a href='/manager/dl.php' class='tooltip' title='System Licences - View Department Status'><b>System Licences</b> - View Department Status</a>", $ma); ?>
	<br/></div>
	
	<div class='sub'><strong class='strong'>System</strong>
	
		<?php 
		if ((isset($ma_acl) && strlen($ma_acl)>='1') || $manager_user=='Manager') {
			if ($manager_user =='Manager' || strpos("007b",$ma_acl)) {
    			$date_access = ', Add And Update';
			} else {
    			$date_access = '';
			}
		}
		?>
		  
	<?php check("009","<a href='alternate_routing.php' class='tooltip' title='Apply Alternate Routing DDIPlans to Trunk Groups'><b>Alternate Routing</b> - Configure Alternate Routing</a>", $ma);
		  check("007","<a href='date_exceptions.php' class='tooltip' title='View{$date_access} Date Exceptions To Timeplans'><b>Date Exceptions</b> - View{$date_access} Bulk Date Exceptions</a>", $ma);
		  check("008","<a href='ddis.php' class='tooltip' title='Update, Amended And Bulk Apply DDI Plan Settings'><b>DDI Plans</b> - Update And Amend DDI Plans</a>", $ma);
		  check("078","<a href='intramoduletrunks.php' class='tooltip' title='Create or Delete IntraModuleTrunks'><b>IntraModuleTrunks</b> - Create or Delete</a>", $ma);
		  check("010","<a href='addresssearch.php' class='tooltip' title='Search The Config For An IP Or MAC Address'><b>IP Or MAC Address</b> - Search Config</a>", $ma);
		  check("011","<a href='commands.php' class='tooltip' title='Basic Linux Commands'><b>Linux Commands</b> - Information And Links</a>", $ma);
		  check("012","<a href='grouped_departments.php' class='tooltip' title='Put Groups Of Departments OutofHours And Play Selected Wav File'><b>Group Departments</b> - Enable OutofHours Messages</a>", $ma);
		  check("083","<a href='portmap.php' class='tooltip' title='View Analogue Port Allocation'><b>PortMap</b> - View Analogue Port Allocation</a>", $ma);
		  check("013","<a href='/manager/movephones.php' class='tooltip' title='Move Phones/PCSs From Module To Module'><b>Move Phones/PCS</b> - Between Modules. Fix POTS</a>", $ma);
		  check("014","<a href='/manager/movehome.php' class='tooltip' title='Move Users Or Departments Voicemail Home'><b>Move Voicemail Home</b> - Users Or Departments</a>", $ma);
		  
		if ((isset($ma_acl) && strlen($ma_acl)>='1') || $manager_user=='Manager') {		  
	  		if ($manager_user =='Manager' || strpos("007b",$ma_acl)) {
    			$sch = ' And Delete';
			}else {
    			$sch = '';
			}
		}
		  
		  check("015","<a href='viewscheduledcalls.php' class='tooltip' title='View{$sch} Scheduled Calls'><b>Scheduled Calls</b> - View{$sch} Scheduled Calls</a>", $ma);
		  check("016","<a href='speeddials.php' class='tooltip' title='Manage Speed Dial Entries. Bulk Add, Remove, Import, Export And Update'><b>Speed Dials</b> - Add, Remove, Import, Export And Update</a>", $ma);
		  check("017","<a href='licenceallocation.php' class='tooltip' title='View And Edit Licence Allocation For Trunks & Voicemail Ports'><b>Trunk And Voicemail Port Licences</b> - View & Edit</a>", $ma);
		  check("018","<a href='trunks.php' class='tooltip' title='Bulk Remove Outgoing Callbar From Trunks'><b>Trunks</b> - Bulk Remove Outgoing Callbar</a>", $ma);
		  check("019","<a href='unassigned.php' class='tooltip' title='View And Selectively Delete Unassigned Phones and Modules'><b>Unassigned</b> - View & Delete Unassigned Phones And Modules</a>", $ma);
		  check("020","<a href='/manager/vlan.cgi' class='tooltip' title='Virtual LAN (VLAN) Config'><b>VLAN</b> - Virtual Lan (VLAN) Config</a>", $ma);
		  check("021","<a href='websetnet.php' class='tooltip' title='Web Based Setnet Script'><b>WebSetnet</b> - Web Based Setnet Script</a>", $ma); ?>
	<br/></div>
	
	<div class='sub'><strong class='strong'>Users</strong>
	<?php check("002","<a href='add_vmcontacts.php?action=2' class='tooltip' title='Add Bulk Voicemail Contacts To A User'><b>Users</b> - Bulk Add Voicemail Contacts</a>", $ma);
		  check("022","<a href='capabilities.php' class='tooltip' title='Bulk Add Or Remove Capabilities To Individual Or Multiple Users. View Capabilities Assigned To Users'><b>Capabilities</b> - Bulk Add, Remove And View Agent and User Capabilities</a>", $ma);
		  check("023","<a href='delete_user.php' class='tooltip' title='Delete A User And Any Associated Group Or DDI Entries'><b>Delete User</b> - With Associated Groups And/Or DDI's</a>", $ma);
		  check("024","<a href='groups.php' class='tooltip' title='View Which Groups A User Is A Member Of'><b>Group Membership</b> - View User Group Memberships</a>", $ma);
		  check("025","<a href='grouprestriction.php' class='tooltip' title='Bulk Enable Or Disable Restrict Groups Against A User'><b>Groups Restrict</b> - Bulk Enable Or Disable Restrict Groups</a>", $ma);
		  check("026","<a href='manage_groups.php' class='tooltip' title='Bulk View, Add Or Remove Users Within An Indiviual Group'><b>Groups Users</b> - Add And Remove Users Within Groups</a>", $ma);
		  check("027","<a href='/manager/moveuserslocation.php' class='tooltip' title='Move Users Location'><b>Move Users</b> - Registered Location</a>", $ma);
		  check("086","<a href='pcs_defaults.php' class='tooltip' title='Change phone default settings. Directory filters, homepage, idlepage, keypad mode headset ringing, overlap dialing, park and dial'><b>PCS IP Phone</b> - Change settings / defaults</a>", $ma);
		  check("028","<a href='/manager/ul.php' class='tooltip' title='System Licences - View User Status'><b>System Licences</b> - View And Update User Licence Status</a>", $ma);
		  check("029","<a href='extension_list.php' class='tooltip' title='List Of Extension Names And Numbers'><b>User Extensions</b> - View Complete List Of Extensions and Usernames</a>", $ma);
		  check("030","<a href='userstatus.php' class='tooltip' title='View Base Configuration, Forwarding, FollowMe, DND, Codes, Licences, Spare Numbers'><b>User Status</b> - View User Configuration & Forwarding Status</a>", $ma); ?>
	<br/></div>

	<div class='sub'><strong class='strong'>Voicemail</strong>
	<?php check("031","<a href='vmaccess_gui.php' class='tooltip' title='Update User & Department Voicemail Access Codes'><b>Voicemail Access Codes</b> - Update Users And/Or Departments Access Codes</a>", $ma);
		  check("032","<a href='guid.php' class='tooltip' title='View And Copy Voicemail Mailbox Guids. Flash Player Required For Copying'><b>Voicemail GUIDS</b> - View And Copy Mailbox GUID's</a>", $ma); ?>
	</div>		  
</div></div>
</li>


<?php check("FAQ","<li><a href='faq.php' class='tooltip' id='faq' title='View And Search Frequently Asked Questions'><h3><img src='images/help.png' style='vertical-align:middle;'>&nbsp;&nbsp;F.A.Q's</h3></a></li>", $ma); ?>

<li><div class='section'>
<a href="#" id="show" class='tooltip' title="Check For Common Configuration Issues"><h3><img src='images/ok.png' style="vertical-align:middle;">&nbsp;&nbsp;System Checks</h3></a>
<div class="slideassist" style="display:block; display:none;">
	<div class='sub'><strong class='strong'>Checks</strong>
	<?php check("037","<a href='recording.php' class='tooltip' title='Check The System To See How Recording Is Configured'><b>Call Recording</b> - Check How Recording Is Configured</a>", $ma); 
		  check("033","<a href='capabilitynames.php' class='tooltip' title='Check Capability Names For Invalid Characters And White Space'><b>Capability Names</b> - Check For Invalid Characters And White Space</a>", $ma);
	 	  check("034","<a href='codes.php' class='tooltip' title='See What Codes Are Configured Against A User, Agent, Department, Port Or Phone'><b>Codes</b> - View And Manage System Codes</a>", $ma); 
	 	  check("076","<a href='connectivity.php' class='tooltip' title='Basic Network Connectivity Tests - DNS, EMAIL, FTP, KeepAlive'><b>Connectivity</b> - Basic Network Connectivity Tests</a>", $ma);
	 	  check("077","<a href='contactscheck.php' class='tooltip' title='Contacts Name Check - Check For Invalid Characters And White Space'><b>Contact Names</b> - Check For Invalid Characters And White Space</a>", $ma);
	 	  check("035","<a href='/manager/imt.php' class='tooltip' title='IntraModuleTrunk Status'><b>IntraModuleTrunk</b> - View Status</a>", $ma); 
	 	  check("036","<a href='namecheck.php' class='tooltip' title='Check Key System Entries For Invalid Characters'><b>Name Check</b> - Check For Invalid Characters. Names, Contacts and Capabilities</a>", $ma); 
	 	  
		  if (file_exists('/SpliceCom/WebManager/assist/notifications.php')) {
			  check("091","<a href='notifications.php' class='tooltip' title='Enable Individual System Email Notifications'><b>Notifications</b> - Enable Individual System Email Notifications</a>", $ma); 
		  }
		  
	 	  check("038","<a href='/manager/sipconfig.php' class='tooltip' title='View SIPConfig And Trunk Status'><b>SIP Config</b> - SIP & Trunk Status</a>", $ma); 
	 	  check("039","<a href='sparenumbers.php' class='tooltip' title='Check Users, Contacts And Company Contacts For Clashes With Internal Numbers'><b>Spare Numbers</b> - Check Spare1 And Spare2</a>", $ma); 
	 	  check("040","<a href='syscheck.php' class='tooltip' title='Check For System Configuration Errors'><b>System Check</b> - Check For System Config Errors</a>", $ma); 
	 	  check("041","<a href='/manager/licences.php' class='tooltip' title='View System Licence Status'><b>System Licences</b> - View System Licence Status</a>", $ma); 
	 	  check("042","<a href='/manager/time.php' class='tooltip' title='Time Check For This Callserver And System'><b>Time Check</b> - For This Callserver And System</a>", $ma); 
	 	  check("043","<a href='timeplans.php' class='tooltip' title='Check Timeplans For Incorrect Time Settings'><b>Time Plans</b> - Check For Incorrect Settings</a>", $ma); ?>
	<br/></div>
	
	<div class='sub'><strong class='strong'>Logging</strong>
	<?php check("044","<a href='log/index.php' class='tooltip' title='View Live System Logs And Set The Debug And Logging Settings For This Callserver Module'><b>Logging</b> - View Live System Logs</a>", $ma);
		  check("088","<a href='fileman.php' class='tooltip' title='Upload and Download files to & from /SpliceCom/ftp, /SpliceCom/logs, /SpliceCom/Web and /SpliceCom/Mailbox'><b>Fileman</b> - Upload and Download Files</a>", $ma);
		  
		  if (strpos($productversion, 'SV') !== false) {
			check("089","<a href='portalaudit.php' class='tooltip' title='View EndUser Portal Logs'><b>Portal Audit</b> - View End User Portal Logs</a>", $ma); 
		  }
		  if (strpos($productversion, 'SV') !== false || strpos($productversion, 'S8') !== false) {
			check("090","<a href='tcpdump.php' class='tooltip' title='TCPDUMP - Capture data packets'><b>TCPDUMP Listener</b> - View, Capture and Download Data Packets</a>", $ma); 
		  }
		  
		  
		  check("045","<a href='webawk.php' class='tooltip' title='AWK System Log Files - Extract Data Between Two Time Points'><b>WebAWK</b> - AWK System Log Files</a>", $ma); ?>
	<br/></div>

	<div class='sub'><strong class='strong'>Statistics</strong>
	<?php 
		$diskspacetitle = file_exists('/SpliceCom/install/assets/vmap') ? 'View Recordings Disk Space' : 'View Current Disk Space And Clear Temporary Session Files';
		  check("046","<a href='log/diskspace.php' class='tooltip' title='$diskspacetitle'><b>Disk Space</b> - $diskspacetitle</a>", $ma);
		  check("047","<a href='/manager/sysstat.php' class='tooltip' title='View System Statistics'><b>System Statistics</b> - View Details</a>", $ma);
		  check("048","<a href='/manager/uptime.php' class='tooltip' title='Admin Module Uptime For This Callserver And System'><b>Uptime</b> - View System Uptime</a>", $ma); ?>
	</div>		  
</div></div>
</li>


<li><div class='section'>
<a href="#" id="show" class='tooltip' title="Manage System Backups and Upgrades"><h3><img src='images/backup.png' style="vertical-align:middle;">&nbsp;&nbsp;System Utilities</h3></a>
<div class="slideassist" style="display:block; display:none;">
	<div class='sub'><strong class='strong'>Backup / Upgrade</strong>
	<?php check("049","<a href='backup.php' class='tooltip' title='Backup System Config And Download Via The Web Browser'><b>Backup Config</b> - Create & Download Via Browser</a>", $ma);
		  check("085","<a href='email.php' class='tooltip' title='Schedule Email Database Backups'><b>Schedule Email Backups</b> - Weekly, Monthly Now</a>", $ma);
		  check("050","<a href='mbackups.php' class='tooltip' title='Download, Delete, Restore Or Rename System Backup Files'><b>Manage Backups</b> - Delete, Rename and Restore</a>", $ma);
		  check("051","<a href='systembackup.php' class='tooltip' title='Create System Backups Including Database, Full, Web, Wav And Voicemail Greetings'><b>System Backups</b> - Web, Wav And Greeting Backups</a>", $ma);
	
		  check("094","<a href='sipphones.php' class='tooltip' title='Yealink SIP Phone Update Server'><b>SIP Phone Update Server</b> - SIP Phone Update Server</a>", $ma);
		  check("095","<a href='stun.php' class='tooltip' title='Update SIP STUN Server Settings'><b>SIP STUN Server</b> - Update SIP STUN Server Settings</a>", $ma);
		  check("052","<a href='ssl.php' class='tooltip' title='PCS 5xx/SSL Update Server'><b>PCS 5xx/SSL Update Server</b> - PCS 5xx/SSL Update Server</a>", $ma);
		  check("053","<a href='uploadconfig.php'class='tooltip' title='Restore System Config, Changemac And View System Passwords'><b>Upload Config</b> - Restore Backup File</a>", $ma);
	
		  check("054","<a href='webpatch.php'class='tooltip' title='Configure And Run Patch.Php Via Your Browser'><b>Web Patch</b> - Configure & Run patch.php</a>", $ma);
		  check("055","<a href='webupgrade.php'class='tooltip' title='Upgrade, Set Time, Report MAC Address, Poweroff and Report Uptime.'><b>Web Upgrade</b> - Upgrade Phones</a>", $ma); 
	?>
	<br/></div>
	
	<div class='sub'><strong class='strong'>Commands</strong>
	<?php check("056","<a href='/manager/manager.cgi?pagename=askmaster' class='tooltip' title='This Facility Is Used When A CallServer Is Added To An Existing System'><b>Ask Master</b> - Add CallServer To Existing System</a>", $ma);
		  check("057","<a href='/manager/manager.cgi?pagename=merge' class='tooltip' title='Used When Connecting A Secondary Call Server To A Primary Call Server'><b>Merge Remote System</b> - Merge A Secondary To A Primary</a>", $ma);
		  check("058","<a href='/manager/manager.cgi?pagename=settime' class='tooltip' title='To Set The Time Used By The System'><b>Set Time</b> - Set System Time</a>", $ma); ?>
	<br/></div>
	
	<div class='sub'><strong class='strong'>Status</strong>
	<?php check("059","<a href='callstatus.php' class='tooltip' title='Updated Callstatus Supporting Trunk Groups, Trunk Status'><b>Call Status</b> - View Live Call Status</a>", $ma);
		  check("087","<a href='notes.php' class='tooltip' title='Notes Manager'><b>Notes</b> - Add, Edit, View and Manage Notes</a>", $ma);
          check("060","<a href='/manager/vm.php' class='tooltip' title='Lists All Voicemail Boxes And The Number Of Unplayed And Total Voicemail Messages For Each Account'><b>Voicemail Status</b> - View Voicemail Status</a>", $ma); ?>
	<br/></div>
	
	<div class='sub'><strong class='strong'>Import/Export</strong>
	<?php check("061","<a href='/manager/files.php' class='tooltip' title='This Script Provides The Ability To Import And Export $files_ma'><b>File Import / Export</b> - Import And Export Settings</a>", $ma);
	 	  check("062","<a href='import_member.php' class='tooltip' title='Import PCS5xx Phones And Users From A CSV File'><b>Import Members</b> - Import PCS5xx Phones And Users From A CSV File</a>", $ma);
	 	  check("063","<a href='make_member.php' class='tooltip' title='Make Unassigned PCS5xx Phones Members. Optionally Create And Associate To Users'><b>Make Member</b> - Make PCS5xx Members</a>", $ma);
	 	  check("064","<a href='/manager/modify.php' class='tooltip' title='Allows User Parameters To Be Modified Off Line Using An Excel Spreadsheet'><b>Modify Users</b> - Via A Spreadsheet</a>", $ma); ?>
	<br/></div>
	
	<div class='sub'><strong class='strong'>Diagnostics</strong>
	<?php 
	
	if (trim($model) == 'CS5100') {
		  check("092","<a href='inittab.php' class='tooltip' title='Configure CS5100 inittab'><B>inittab</b> - Configure CS5100 inittab</a>", $ma);
	}
		  check("065","<a href='/manager/ipaddresses.php' class='tooltip' title='Lists Ip Addresses Against Associated Name And Mac Address'><B>IP Addresses</b> - View IP Addresses and Associated Names and MAC Addresses</a>", $ma);
		  check("096","<a href='/manager/assist/ipcs.php' class='tooltip' title='Clear iPCS iOS Push Registrations'><b>iPCS</b> - Clear iPCS iOS Push Registrations</a>", $ma);
	 	  check("066","<a href='/manager/snmp.php' class='tooltip' title='Demonstration SNMP Page'><b>SNMP</b> - Simple Network Management Protocol Demonstration Page</a>", $ma);
	 	  check("067","<a href='/manager/sorted.php' class='tooltip' title='Sorts By Name, Extension & Initial Phone And Searches For Duplicate Entries. Also Lists By Physical Phone'><b>Sorted</b> - Sorted Lists Of Users, Phones and Extensions</a>", $ma);
	 	  check("068","<a href='/manager/users.php' class='tooltip' title='Checks That User Locations Are Consistent Across All Active Call Servers'><b>User Locations</b> - Check User Locations</a>", $ma);
	 	  check("069","<a href='/manager/warnings.php' class='tooltip' title='This Screen Provides A List Of Each Reboot Of The System And Licence Error Warnings'><b>Warnings</b> - View System Warnings</a>", $ma); ?>
	</div>
</div></div>
</li>

<li><div class='section'>
<a href="#" id="show" class='tooltip' title="System Configuration Wizards"><h3><img src='images/wizards.png' style="vertical-align:middle;">&nbsp;&nbsp;System Wizards</h3></a>
<div class="slideassist" style="display:block; display:none;">
	<div class='sub'><strong class='strong'>Wizards</strong>
	<?php check("070","<a href='duplicate.php' class='tooltip' title='Duplicate Users, Dialplans, Lcrplans, Departments And Groups'><b>Duplicate</b> - Various System Settings</a>", $ma);
	 	  check("071","<a href='pcs5xx.php' class='tooltip' title='Upload Logo And Ringtunes For The PCS5XX & PCS5X1 IP Phones. Site File Creation'><b>PCS5xx Logos</b> - Create PCS5xx & PCS5x1 Site Files</a>", $ma);
	 	  check("072","<a href='/manager/screensaver.php' class='tooltip' title='Quick PCSXXX Screensaver Configuration'><b>PCS5xx Screen Saver</b> - Quick PCSxxx Configuration</a>", $ma);
	 	  check("073","<a href='../admin/sipwizard' class='tooltip' title='Create SIP / Teams Modules, Trunks, Lcrplan And Dialplan Entries'><b>SIP / Teams Trunks</b> - Guided Wizard</a>", $ma);
	 	  check("074","<a href='administrator.php' class='tooltip' title='Create System Administrators'><b>System Administrators</b> - Create and Configure</a>", $ma);
		  
		  if (strpos($productversion, 'SV') !== false) {
			check("093","<a href='wallpaper.php' class='tooltip' title='Configure custom yealink wallpaper files'><b>Wallpaper</b> - Create custom Yealink wallpaper config file</a>", $ma); 
		  }
		  
		  check("075","<a href='wavupload.php' class='tooltip' title='Upload WAV Files To Users, Departments, AutoAttendants and Music Channels'><b>Wav Upload</b> - Users, Departments, AA & MoH</a>", $ma); 
	?>
	</div>	 	  
</div></div>
</li>
</ul></div></div>
</body>
</html>